/*****************************************************************************************
******************************************************************************************
Nom du fichier:SOMO14D.h
------------------------------------------------------------------------------------------
Auteur: Philippe MARIANO
------------------------------------------------------------------------------------------
Rle: fichier d'en-tte de la librairie SOMO14D.lib
------------------------------------------------------------------------------------------
Cr le : 02/03/2011
Dernire rvision le :
Paramtrage le 28/04/2011 pour la carte MICRODESIGN
  
------------------------------------------------------------------------------------------
Cross compilateur utilis: CodeVisionAVR V2.04.08
------------------------------------------------------------------------------------------
Composants cibles : ATMEL 8 bits
------------------------------------------------------------------------------------------
CIBLE HARDWARE: Carte pour les TP ATMEL SSI V1 ou V2
------------------------------------------------------------------------------------------
Remarques:
Ce fichier est destin  un projet CVAVR utilisant la carte SSI
Il doit tre plac dans le sous rpertoire \CVAVR\INC\ ou dans le rpertoire du projet
Placer le fichier SOMO14D.lib dans le rpertoire \CVAVR\LIB\ ou dans le rpertoire du projet 
*****************************************************************************************
*****************************************************************************************/

#ifndef _SOMO14D_INCLUDED_         // Evite que le fichier ne soit inclus plusieurs fois
#define _SOMO14D_INCLUDED_

// *****************************************************************************************
// Dfinitions
// *****************************************************************************************
// Affectation des broches du microcontrleur connect au module SOMO-14D
// -----------------------------------------------------------------------------------------
#define Data            PORTA.0         // Sortie: signal des donnes 
#define Clk             PORTA.1         // Sortie: Signal d'horloge
#define Reset           PORTA.2         // Sortie: signal de remise  zro
#define Busy            PINA.3          // Entre: = 1 si un fichier est en cours de lecture
// -----------------------------------------------------------------------------------------
#define VolumeMax       7               // Incrment maximum pour le rglage du volume
                                        // 0xFFF0  0xFFF7
// -----------------------------------------------------------------------------------------
// Commande du module SOMO-14D
// -----------------------------------------------------------------------------------------
#define PlayPause       0xFFFE
#define Stop            0xFFFF
// -----------------------------------------------------------------------------------------
// *****************************************************************************************

// *****************************************************************************************
// Fonctions (Rcapitulatif)
// *****************************************************************************************
// 0) void InitSOMO14D(void);
// 1) void AttendreFinSonSomo14D(void);
// 2) void Somo14DReset(void);
// 3) void Somo14DStart(void);
// 4) void Somo14DStop(void);
// 5) void Somo14DTransfertInt(unsigned int Value);
// 6) void Somo14DReglageVolume(unsigned char Volume); 
// 7) void SendFrameToSomo14D(unsigned int value);
// *****************************************************************************************
void InitSOMO14D(void);
/* -----------------------------------------------------------------------------------------
Rle : Mettre  "1" les lignes CLK et RESET et appeler la fonction Somo14DReset().

Entres / sortie : rien
------------------------------------------------------------------------------------------*/
void AttendreFinSonSomo14D(void);
/* -----------------------------------------------------------------------------------------
Rle : Bloque la squence de slection des fichiers tant qu'un fichier est en cours de 
lecture. 

Entres / sortie : rien
------------------------------------------------------------------------------------------*/
void Somo14DReset(void);
/* -----------------------------------------------------------------------------------------
Rle : Rinitialiser le module conformment aux chronogrammes de la documentation.

Commentaires : tRP = 10ms - tRESET = 500ms

Entres / sortie : rien
------------------------------------------------------------------------------------------*/
void Somo14DStart(void);
/* -----------------------------------------------------------------------------------------
Rle : Gnrer un Start conformment aux chronogrammes de la documentation.

Commentaires : tSTART = 2,5ms

Entres / sortie : rien
------------------------------------------------------------------------------------------*/
void Somo14DStop(void);
/* -----------------------------------------------------------------------------------------
Rle : Gnrer un Stop conformment aux chronogrammes de la documentation.

Commentaires : tSTOP = 2,5ms

Entres / sortie : rien
------------------------------------------------------------------------------------------*/
void Somo14DTransfertInt(unsigned int Value);
/* -----------------------------------------------------------------------------------------
Rle : Srialiser une donne sur 16 bits sur la sortie DATA et gnrer le signal d'horloge
Clk conformment aux chronogrammes de la documentation.

Commentaires :  tCH = tCL = 150s

Entre :        Value      16bits          variable  srialiser sur la sortie DATA

Sortie :        rien
------------------------------------------------------------------------------------------*/
void Somo14DReglageVolume(unsigned char Volume);
/* -----------------------------------------------------------------------------------------
Rle : Rgler le volume de la sortie audio du module.

Commentaires : 0 min    7 max

Entres     : Volume        octet       incrment de rglage du volume compris entre 0 et 7
Sortie      : rien
------------------------------------------------------------------------------------------*/
void SendFrameToSomo14D(int Value);
/* -----------------------------------------------------------------------------------------
Rle : Envoyer donne au module SOMO-14D

Commentaires :  Cette fonction envoie une trame comprenant  :    | Start | Value | Stop |
                Value peut prendre la valeur "PlayPause", "Stop" dfinie ci-dessus ou tre 
                une adresse de fichier comprise entre 0000h et 01FFh.

Entre : Value      mots 16 bits
sortie : rien
------------------------------------------------------------------------------------------*/

#pragma used-

#pragma library SOMO14D.lib

#endif    // termine la directive ifndef